pyprocar.io.vasp.Outcar — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.vasp.Outcar

class pyprocar.io.vasp.Outcar(filename: str | Path = 'OUTCAR')

  A class to parse the OUTCAR file from a VASP run and extract electronic structure data.

  The OUTCAR file provides detailed output of a VASP run, including a summary of used input parameters, information about electronic steps and KS-eigenvalues, stress tensors, forces on atoms, local charges and magnetic moments, and dielectric properties. The amount of output written onto the OUTCAR file can be chosen by modifying the NWRITE tag in the INCAR file.

  The Outcar class acts as a Mapping, providing key-value access to the variables parsed from the OUTCAR file.

  Parameters:

    filename (Union[str, Path], optional) – The OUTCAR filename. If not provided, defaults to “OUTCAR”.

  Variables:

    - variables (dict) – A dictionary storing variables parsed from the OUTCAR file.

    - filename (Path) – The path to the OUTCAR file.

    - file_str (str) – The full string content of the OUTCAR file.

  Methods

  `Outcar.__init__`([filename]) | Constructor method to initialize an Outcar object.
  `Outcar.get_symmetry_operations`() |

  Attributes

  `Outcar.efermi` | Just finds all E-fermi fields in the outcar file and keeps the last one (if more than one found).
  `Outcar.reciprocal_lattice` | Finds and return the reciprocal lattice vectors, if more than one set present, it return just the last one.
  `Outcar.rotations` | Finds the point symmetry operations included in the OUTCAR file and returns them in matrix form.